package service

import (
	"XT_New/models"
	"github.com/jinzhu/gorm"
	"time"
)

func GetHisProjectIsExist(projectName string, orgid int64) (*models.XtHisProject, error) {

	var project models.XtHisProject
	var err error
	err = XTReadDB().Model(&project).Where("project_name = ? and user_org_id = ? and status = 1", projectName, orgid).Find(&project).Error
	if err == gorm.ErrRecordNotFound {
		return nil, err
	}

	if err != nil {
		return nil, err
	}

	return &project, nil
}

func CreateHisProject(project *models.XtHisProject) error {

	err := XTWriteDB().Model(&project).Create(&project).Error
	return err
}

func GetHisProjectList(orgid int64, limit int64, page int64, start int64, charge int64, keyword string) (hisproject []*models.XtHisProject, total int64, err error) {
	offset := (page - 1) * limit
	likeKey := "%" + keyword + "%"
	db := XTReadDB().Table("xt_his_project as x").Where("x.status = 1")
	if orgid > 0 {
		db = db.Where("x.user_org_id = ?", orgid)
	}
	if start > 0 {
		db = db.Where("x.medical_status = ?", start)
	}
	if charge > 0 {
		db = db.Where("x.is_charge = ? ", charge)
	}
	if len(keyword) > 0 {
		db = db.Where("x.project_name like ?", likeKey)
	}
	err = db.Select("x.id,x.project_name,x.pinyin,x.wubi,x.price,x.unit,x.cost_classify,x.executive_section,x.medical_coverage,x.statistical_classification,x.disease_directory,x.is_record,x.medical_code,x.tube_color,x.medical_status,x.remark,x.sign,x.default_number,x.is_default,x.is_charge,x.is_estimate,x.is_workload,x.sort,x.doctor_advice,x.user_org_id,x.status,x.created_time").Count(&total).Offset(offset).Limit(limit).Find(&hisproject).Error
	return hisproject, total, err
}

func GetProjectDetail(id int64) (models.XtHisProject, error) {
	project := models.XtHisProject{}
	err := XTReadDB().Model(&project).Where("id=? and status = 1", id).Find(&project).Error
	return project, err
}

func UpdatedProject(id int64, pro *models.XtHisProject) error {

	err := XTWriteDB().Model(&pro).Where("id=?", id).Updates(map[string]interface{}{"project_name": pro.ProjectName, "pinyin": pro.Pinyin, "wubi": pro.Pinyin, "price": pro.Price, "unit": pro.Unit, "cost_classify": pro.CostClassify, "executive_section": pro.ExecutiveSection, "medical_coverage": pro.MedicalCoverage, "statistical_classification": pro.MedicalCoverage, "disease_directory": pro.DiseaseDirectory, "is_record": pro.DiseaseDirectory, "medical_code": pro.MedicalCode, "tube_color": pro.TubeColor, "medical_status": pro.MedicalStatus, "remark": pro.Remark, "sign": pro.Sign, "default_number": pro.DefaultNumber, "is_default": pro.IsDefault, "is_charge": pro.IsCharge, "is_estimate": pro.IsEstimate, "is_workload": pro.IsWorkload, "sort": pro.Sort, "doctor_advice": pro.DoctorAdvice, "single_dose": pro.SingleDose, "execution_frequency": pro.ExecutionFrequency, "delivery_way": pro.ExecutionFrequency, "number_days": pro.ExecutionFrequency, "total": pro.Total, "updated_time": pro.UpdatedTime}).Error
	return err
}

func DeleteHisProject(id int64) error {
	project := models.XtHisProject{}
	err := XTWriteDB().Model(&project).Where("id=?", id).Updates(map[string]interface{}{"status": 0}).Error
	return err
}

func GetHisProjectByNameOne(projectName string, orgid int64) (*models.XtHisProjectTeam, error) {

	projectTeam := models.XtHisProjectTeam{}
	err := XTReadDB().Model(&projectTeam).Where("project_team = ? and user_org_id = ? and status = 1", projectName, orgid).Find(&projectTeam).Error
	if err != nil {
		if err == gorm.ErrRecordNotFound {
			return nil, err
		} else {
			return nil, err
		}
	}
	return &projectTeam, nil

}

func CreatedProjectTeam(team *models.XtHisProjectTeam) error {

	err := XTWriteDB().Model(&team).Create(&team).Error
	return err
}

func GetProjectTeamList(limit int64, page int64, orgid int64, keyword string) (projectTeam []*models.XtHisProjectTeam, total int64, err error) {
	offset := (page - 1) * limit
	likeKey := "%" + keyword + "%"
	db := XTReadDB().Model(&projectTeam)
	if len(keyword) > 0 {
		db = db.Where("project_team like ?", likeKey)
	}
	err = db.Where("user_org_id = ? and status = 1", orgid).Count(&total).Offset(offset).Limit(limit).Order("created_time desc").Find(&projectTeam).Error
	return projectTeam, total, err
}

func GetProjectTeamDetail(id int64) (models.XtHisProjectTeam, error) {

	projectTeam := models.XtHisProjectTeam{}
	err := XTReadDB().Model(&projectTeam).Where("id= ? and status = 1", id).Find(&projectTeam).Error
	return projectTeam, err
}

func UpdatedProjectTeam(id int64, team *models.XtHisProjectTeam) error {

	err := XTWriteDB().Model(&team).Where("id=? and status = 1", id).Updates(map[string]interface{}{"project_team": team.ProjectTeam, "price": team.Price, "pinyin": team.Pinyin, "wubi": team.Wubi, "tube_color": team.TubeColor, "team_type": team.TeamType, "remark": team.Remark, "project_id": team.ProjectId}).Error
	return err
}

func DeleteProjectTeam(id int64) error {

	team := models.XtHisProjectTeam{}
	err := XTWriteDB().Model(&team).Where("id = ? and status = 1", id).Updates(map[string]interface{}{"status": 0}).Error
	return err
}

func CreateDePartment(department *models.XtHisDepartment) error {

	err := XTWriteDB().Model(&department).Create(&department).Error
	return err
}

func GetDepartMentList(limit int64, page int64, orgid int64) (departMent []*models.XtHisDepartment, total int64, err error) {

	offset := (page - 1) * limit
	err = XTReadDB().Model(&departMent).Where("user_org_id = ? and status = 1", orgid).Count(&total).Offset(offset).Limit(limit).Order("created_time desc").Find(&departMent).Error
	return departMent, total, err
}

func GetDepartMentDetail(id int64) (models.XtHisDepartment, error) {

	department := models.XtHisDepartment{}
	err := XTReadDB().Model(&department).Where("id=? and status = 1", id).Find(&department).Error
	return department, err
}

func UpdatedDepartment(id int64, department *models.XtHisDepartment) error {

	err := XTWriteDB().Model(&department).Where("id=? and status = 1", id).Updates(map[string]interface{}{"name": department.Name, "number": department.Number, "updated_time": time.Now().Unix()}).Error
	return err
}

func DeleteDepartment(id int64) error {
	department := models.XtHisDepartment{}
	err := XTReadDB().Model(&department).Where("id=? and status = 1", id).Updates(map[string]interface{}{"status": 0}).Error
	return err
}

func GetBloodPatientList(orgid int64, startime int64) (schedule []*models.SchedulesVm, err error) {

	db := XTReadDB().Table("xt_schedule as x").Where("x.status = 1")
	if orgid > 0 {
		db = db.Where("x.user_org_id = ?", orgid)
	}
	if startime > 0 {
		db = db.Where("x.schedule_date = ?", startime)
	}
	err = db.Select("x.id,x.user_org_id,x.patient_id,x.schedule_date,x.schedule_type,x.schedule_week,x.mode_id,p.name,p.id_card_no").Joins("left join xt_patients as p on p.id = x.patient_id").Scan(&schedule).Error
	return schedule, err
}

func GetHisPatient(orgid int64, recorddate int64) (paitent []*models.HisPatient, err error) {

	err = XTReadDB().Model(&paitent).Where("user_org_id = ?  and record_date = ? and status = 1", orgid, recorddate).Find(&paitent).Error
	return paitent, err
}

func GetHisPrescriptionOther(orgid int64, recorddate int64) (prescription []*models.HisPrescriptionVm, err error) {

	db := XTReadDB().Table("his_prescription as x").Where("x.status = 1")
	if orgid > 0 {
		db = db.Where("x.user_org_id = ?", orgid)
	}
	if recorddate > 0 {
		db = db.Where("x.record_date = ? ", recorddate)
	}
	err = db.Select("x.id,x.user_org_id,x.record_date,x.patient_id,x.his_patient_id,x.number,x.type,x.doctor,x.creator,x.modifier,t.name").Joins("left join his_patient as t on t.id = x.his_patient_id").Scan(&prescription).Error
	return prescription, err
}

func GetHisPrescriptionByPatientId(id int64, recordate int64) (prescription []*models.HisPrescription, err error) {

	err = XTReadDB().Model(&prescription).Where("his_patient_id = ? and record_date = ? and status= 1", id, recordate).Find(&prescription).Error
	return prescription, err
}

func CreateAdditionalCharge(charge *models.HisAdditionalCharge) error {

	err = XTWriteDB().Model(&charge).Create(&charge).Error
	return err
}

func GetTreatmentList(id int64, startime int64) (prescription []*models.HisPrescription, err error) {

	err = XTReadDB().Model(&prescription).Where("id = ? and record_date = ? and status = 1", id, startime).Find(&prescription).Error
	return prescription, err
}

//func GetAllProjectList(orgid int64) (project []*models.XtHisProject, err error) {
//
//	err = XTReadDB().Model(&project).Where("user_org_id = ? and status = 1", orgid).Find(&project).Error
//	return project, err
//}

func CreateProjectList(list *models.XtHisProjectList) error {

	err := XTWriteDB().Model(&list).Create(&list).Error
	return err
}

func GetHisProjectListByOrgId(orgid int64) (projectlist []*models.HisProjectListVm, err error) {

	db := XTReadDB().Table("xt_his_project_list as x").Where("x.status = 1")
	if orgid > 0 {
		db = db.Where("x.user_org_id = ? ", orgid)
	}
	err = db.Select("x.id,x.number,x.user_org_id,x.project_id,t.price,t.unit,t.cost_classify,t.project_name").Joins("left join xt_his_project as t on t.id = x.project_id").Scan(&projectlist).Error
	return projectlist, err
}

func GetHisPatientInformation(id int64) (models.HisPatient, error) {

	patient := models.HisPatient{}
	err := XTReadDB().Model(&patient).Where("id= ? and status = 1", id).Find(&patient).Error
	return patient, err
}

func DeleteProjectList(id int64) error {
	list := models.XtHisProjectList{}
	err := XTWriteDB().Model(&list).Where("id=? and status = 1", id).Updates(map[string]interface{}{"status": 0}).Error
	return err
}

func GetHisProject(orgid int64) (project []*models.XtHisProject, err error) {

	err = XTReadDB().Model(&project).Where("user_org_id = ? and status =1", orgid).Find(&project).Error
	return project, err
}

func GetProjectTeam(ids []string, orgid int64) (project []*models.XtHisProject, err error) {

	err = XTReadDB().Model(&project).Where("user_org_id = ? and id in (?)", orgid, ids).Find(&project).Error
	return project, err
}

func GetAllDepartMent(orgid int64) (department []*models.XtHisDepartment, err error) {

	err = XTReadDB().Model(&department).Where("user_org_id = ? and status =1", orgid).Find(&department).Error
	return department, err
}

func CreateHisPatient(patient *models.XtHisPatient) error {

	err := XTReadDB().Model(&patient).Create(&patient).Error
	return err
}

func GetBloodPatientByIdCard(idcard string, orgid int64) (*models.XtPatients, error) {
	var patients models.XtPatients
	var err error
	err = XTReadDB().Model(&patients).Where("id_card_no = ? and user_org_id = ? and status = 1", idcard, orgid).Find(&patients).Error
	if err != nil {
		if err == gorm.ErrRecordNotFound {
			return nil, err
		} else {
			return nil, err
		}
	}
	return &patients, nil
}

func GetAllProjectTeam(orgid int64) (project []*models.XtHisProjectTeam, err error) {

	err = XTReadDB().Model(&project).Where("user_org_id = ? and status = 1", orgid).Find(&project).Error
	return project, err
}

func GetProjectListById(orgid int64, ids []string) (project []*models.XtHisProject, err error) {
	err = XTReadDB().Model(&project).Where("user_org_id = ? and id in (?)", orgid, ids).Find(&project).Error
	return project, err
}

func GetHisPatientHistory(keyword string, startime int64, endtime int64, registtype int64, limit int64, page int64, orgid int64) (hisPatient []*models.XtHisPatient, total int64, err error) {
	offset := (page - 1) * limit
	likeKey := "%" + keyword + "%"
	db := XTReadDB().Table("his_patient as x").Where("x.status = 1")

	if len(keyword) > 0 {
		db = db.Where("x.name like ?", likeKey)
	}
	if startime > 0 {
		db = db.Where("x.record_date >= ?", startime)
	}
	if endtime > 0 {
		db = db.Where("x.record_date<=?", endtime)
	}
	if registtype > 0 {
		db = db.Where("x.register_type = ?", registtype)
	}
	if orgid > 0 {
		db = db.Where("x.user_org_id = ?", orgid)
	}
	err = db.Select("x.id,x.balance_accounts_type,x.medical_insurance_number,x.name,x.gender,x.id_type,x.medical_treatment_type,x.birthday,x.record_date,x.age,x.phone_number,x.id_card_no,x.register_type,x.admin_user_id,x.departments,x.is_need_cost_of_production,x.register_cost,x.treatment_cost,x.cost_of_production,x.total,x.user_org_id,x.patient_id,x.number").Count(&total).Offset(offset).Limit(limit).Find(&hisPatient).Error
	return hisPatient, total, err
}
